<?php
/*
Plugin Name: WP Client Reports Simple Integration
Plugin URI: https://switchwp.com/wp-client-reports/
Description: An example simple integration plugin
Version: 1.0.0
Author: You
Author URI: https://you.com/
*/

if( !defined( 'ABSPATH' ) )
	exit;


/**
 * Add scripts and styles into the admin as needed
 */
function wp_client_reports_scripts_simple_integration() {

    $screen = get_current_screen();
    if($screen && $screen->id == 'dashboard_page_wp_client_reports') {
        //wp_enqueue_style( 'wp-client-reports-simple-integration-css', plugin_dir_url( __FILE__ ) . '/css/wp-client-reports-simple-integration.css', array(), '1.0.0' );
        wp_enqueue_script( 'wp-client-reports-simple-integration-js', plugin_dir_url( __FILE__ ) . 'js/wp-client-reports-simple-integration.js', array('jquery'), '1.0.0', true );
    }

}
add_action( 'admin_print_scripts', 'wp_client_reports_scripts_simple_integration', 11 );


/**
 * Load Your Simple Integration Actions
 */
add_action( 'init', 'wp_client_reports_pro_load_simple_integration_actions', 999 );
function wp_client_reports_pro_load_simple_integration_actions(){

    if (is_admin() || wp_doing_cron()) {
    
        add_action('wp_client_reports_stats', 'wp_client_reports_stats_page_simple_integration', 15);
        add_action('wp_client_reports_stats_email', 'wp_client_reports_stats_email_simple_integration', 15, 2);
        add_action('wp_ajax_wp_client_reports_simple_integration_data', 'wp_client_reports_simple_integration_data');

    }

}


/**
 * Ajax request report data for Your Simple Integration
 */
function wp_client_reports_simple_integration_data() {

    $start = null;
    $end = null;
    if (isset($_GET['start'])) {
        $start = sanitize_text_field($_GET['start']);
    }
    if (isset($_GET['end'])) {
        $end = sanitize_text_field($_GET['end']);
    }

    $dates = wp_client_reports_validate_dates($start, $end);

    $data = wp_client_reports_get_simple_integration_data($dates->start_date, $dates->end_date);

    print json_encode($data);
    wp_die();

}


/**
 * Get data for Your Simple Integration
 */
function wp_client_reports_get_simple_integration_data($start_date, $end_date) {

    $timezone = wp_timezone();

    $start_date_object = new DateTime($start_date . " 00:00:00", $timezone);
    $start_date_object->setTimezone(new DateTimeZone('UTC'));
    $start_date_timestamp = $start_date_object->format('U');

    $end_date_object = new DateTime($end_date . " 23:59:59", $timezone);
    $end_date_object->setTimezone(new DateTimeZone('UTC'));
    $end_date_timestamp = $end_date_object->format('U');


    // This is where you would get your own data from your custom source. 

    $data = new stdClass;
    $data->custom_value_1 = 23;
    $data->custom_value_2 = 98;
    $data->custom_value_3 = 42;
    $data->custom_value_4 = 11;

    
    // If it is from an API it might look something like this:

    // $args = array( 'headers' => array( 'Authorization' => 'Bearer ' . $an_api_key ) );
    // $response = wp_remote_get( 'https://api.something.com', $args );
    // if ( is_wp_error( $response ) ) {
    //     return $response;
    // } else {
    //     $the_api_data = json_decode($response['body']);
    //     //Do something with the data
    // }

    
    // If it is from a the database it might look something like this:

    // global $wpdb;
    // $my_simple_integration_table_name = $wpdb->prefix . 'my_simple_integration';
    // $update_results = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $my_simple_integration_table_name WHERE `version_before` IS NOT NULL AND `date` >= %s AND `date` <= %s ORDER BY `date` ASC", array($start_date, $end_date) ) );
    
    return $data;
}


/**
 * Report page section for Your Simple Integration
 */
function wp_client_reports_stats_page_simple_integration() {
    ?>
        <div class="metabox-holder">
            <div class="postbox wp-client-reports-postbox loading" id="wp-client-reports-simple-integration">
                <div class="postbox-header">
                    <h2 class="hndle"><?php _e('My Simple Integration','wp-client-reports'); ?></h2>
                </div>
                <div class="inside">
                    <div class="main">
                        <div class="wp-client-reports-big-numbers">
                            <?php 
                                wp_client_reports_render_big_number(
                                    'Custom<br>Value 1', 
                                    'wp-client-reports-simple-integration-custom-value-1'
                                );
                                wp_client_reports_render_big_number(
                                    'Custom<br>Value 2',
                                    'wp-client-reports-simple-integration-custom-value-2'
                                );
                                wp_client_reports_render_big_number(
                                    'Custom<br>Value 3',
                                    'wp-client-reports-simple-integration-custom-value-3'
                                );
                                wp_client_reports_render_big_number(
                                    'Custom<br>Value 4',
                                    'wp-client-reports-simple-integration-custom-value-4'
                                );
                            ?>
                        </div><!-- .wp-client-reports-big-numbers -->
                    </div><!-- .inside -->
                </div><!-- .main -->
            </div><!-- .postbox -->
        </div><!-- .metabox-holder -->
    <?php
}


/**
 * Report email section for Your Simple Integration
 */
function wp_client_reports_stats_email_simple_integration($start_date, $end_date) {
    $simple_integration_data = wp_client_reports_get_simple_integration_data($start_date, $end_date);

    wp_client_reports_render_email_header('My Simple Integration');

    wp_client_reports_render_email_row(
        $simple_integration_data->custom_value_1, 
        'Custom<br>Value 1',
        $simple_integration_data->custom_value_2, 
        'Custom<br>Value 2',
    );

    wp_client_reports_render_email_row(
        $simple_integration_data->custom_value_3, 
        'Custom<br>Value 3',
        $simple_integration_data->custom_value_4, 
        'Custom<br>Value 4',
    );

}